<?php
/**
 * Plugin Name: WooCommerce Bank Transfer Manager
 * Description: Gerencia pagamentos via transferência bancária no WooCommerce.
 * Version: 1.0
 * Author: Cubo Mágico Design
 */

// Evitar acesso direto
if (!defined('ABSPATH')) {
    exit;
}

// Adicionar submenu ao WooCommerce
add_action('admin_menu', function () {
    add_submenu_page(
        'woocommerce',
        __('Gestão Transferências Bancárias', 'woocommerce-bank-transfer'),
        __('Transferências Bancárias', 'woocommerce-bank-transfer'),
        'manage_woocommerce',
        'wc-bank-transfer-manager',
        'wc_bank_transfer_manager_page'
    );
});

// Exibir página do submenu
function wc_bank_transfer_manager_page()
{
    global $wpdb;
    
    // Pesquisa
    $search_query = isset($_GET['s']) ? sanitize_text_field($_GET['s']) : '';
    $search_sql = '';

    if (!empty($search_query)) {
        $search_sql = $wpdb->prepare(
            " AND (pm1.meta_value LIKE %s OR pm2.meta_value LIKE %s OR pm3.meta_value LIKE %s OR o.id LIKE %s)",
            '%' . $wpdb->esc_like($search_query) . '%',
            '%' . $wpdb->esc_like($search_query) . '%',
            '%' . $wpdb->esc_like($search_query) . '%',
            '%' . $wpdb->esc_like($search_query) . '%'
        );
    }

    // Consultar pedidos
    $results = $wpdb->get_results(
        "SELECT o.id AS order_id, 
                IFNULL(CONCAT(pm1.meta_value, ' ', pm2.meta_value), '') AS customer_name, 
                IFNULL(pm3.meta_value, '') AS account_holder, 
                IFNULL(pm4.meta_value, 'no') AS payment_confirmed,
                o.post_date AS order_date
         FROM {$wpdb->prefix}posts o
         LEFT JOIN {$wpdb->prefix}postmeta pm1 ON o.ID = pm1.post_id AND pm1.meta_key = '_billing_first_name'
         LEFT JOIN {$wpdb->prefix}postmeta pm2 ON o.ID = pm2.post_id AND pm2.meta_key = '_billing_last_name'
         LEFT JOIN {$wpdb->prefix}postmeta pm3 ON o.ID = pm3.post_id AND pm3.meta_key = '_account_holder_name'
         LEFT JOIN {$wpdb->prefix}postmeta pm4 ON o.ID = pm4.post_id AND pm4.meta_key = '_payment_confirmed'
         WHERE o.post_type = 'shop_order' $search_sql
         ORDER BY o.ID DESC",
        ARRAY_A
    );

    echo '<div class="wrap">
            <h1 style="font-size: 24px; font-weight: bold; color: #ff5722; margin-bottom: 20px;">' . __('Gestão de Transferências Bancárias', 'woocommerce-bank-transfer') . '</h1>
            <form method="get" style="margin-bottom: 20px;">
                <input type="hidden" name="page" value="wc-bank-transfer-manager">
                <input type="text" name="s" placeholder="Pesquisar..." value="' . esc_attr($search_query) . '" style="width: 300px; padding: 8px; border: 1px solid #0073aa; border-radius: 4px; margin-right: 10px;" />
                <button type="submit" class="button button-primary" style="padding: 8px 15px; background-color: #ff5722; border-color: #e64a19;">Pesquisar</button>
                <a href="' . admin_url('admin.php?page=wc-bank-transfer-manager') . '" class="button" style="padding: 8px 15px; background-color: #607d8b; border-color: #455a64; color: #fff; text-decoration: none;">Limpar Filtro</a>
            </form>
            <table class="widefat fixed" style="border-collapse: collapse; margin-top: 10px; background-color: #fff;">
                <thead>
                    <tr style="background-color: #ffc107; color: #000; border-bottom: 2px solid #ff9800;">
                        <th style="padding: 10px; text-align: left;">' . __('ID Encomenda', 'woocommerce-bank-transfer') . '</th>
                        <th style="padding: 10px; text-align: left;">' . __('Data da Compra', 'woocommerce-bank-transfer') . '</th>
                        <th style="padding: 10px; text-align: left;">' . __('Nome do Cliente', 'woocommerce-bank-transfer') . '</th>
                        <th style="padding: 10px; text-align: left;">' . __('Titular(es) da Conta Bancária', 'woocommerce-bank-transfer') . '</th>
                        <th style="padding: 10px; text-align: left;">' . __('Pagamento Confirmado', 'woocommerce-bank-transfer') . '</th>
                    </tr>
                </thead>
                <tbody>';

    if ($results) {
        foreach ($results as $row) {
            echo '<tr style="border-bottom: 1px solid #eee; background-color: #f9f9f9;">
                    <td style="padding: 10px; color: #3f51b5; font-weight: bold;">' . esc_html($row['order_id']) . '</td>
                    <td style="padding: 10px; color: #ff5722;">' . esc_html(date('d/m/Y', strtotime($row['order_date']))) . '</td>
                    <td style="padding: 10px;">' . esc_html($row['customer_name']) . '</td>
                    <td style="padding: 10px;">
                        <form method="post" action="' . admin_url('admin-post.php') . '" style="margin: 0;">
                            <input type="hidden" name="action" value="update_account_holder">
                            <input type="hidden" name="order_id" value="' . esc_attr($row['order_id']) . '" />
                            <textarea name="account_holder" rows="2" style="width: 100%; padding: 5px; border: 1px solid #3f51b5; border-radius: 4px;">' . esc_textarea($row['account_holder']) . '</textarea>
                            <button type="submit" class="button button-secondary" style="margin-top: 5px; background-color: #ff9800; border-color: #e65100;">' . __('Atualizar', 'woocommerce-bank-transfer') . '</button>
                        </form>
                    </td>
                    <td style="padding: 10px;">
                        <form method="post" action="' . admin_url('admin-post.php') . '" style="margin: 0;">
                            <input type="hidden" name="action" value="update_payment_status">
                            <input type="hidden" name="order_id" value="' . esc_attr($row['order_id']) . '" />
                            <select name="payment_confirmed" onchange="this.form.submit()" style="padding: 5px; border: 1px solid #00796b; border-radius: 4px; background-color: #b2dfdb;">
                                <option value="no" ' . selected($row['payment_confirmed'], 'no', false) . '>Não Confirmado</option>
                                <option value="yes" ' . selected($row['payment_confirmed'], 'yes', false) . '>Confirmado</option>
                            </select>
                        </form>
                    </td>
                  </tr>';
        }
    } else {
        echo '<tr><td colspan="5" style="padding: 10px; text-align: center; color: #999;">' . __('Nenhuma encomenda encontrada.', 'woocommerce-bank-transfer') . '</td></tr>';
    }

    echo '</tbody>
            </table>
        </div>';
}

// Atualizar titulares da conta bancária
add_action('admin_post_update_account_holder', function () {
    if (!current_user_can('manage_woocommerce')) {
        return;
    }

    $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
    $account_holder = isset($_POST['account_holder']) ? sanitize_textarea_field($_POST['account_holder']) : '';

    if ($order_id) {
        update_post_meta($order_id, '_account_holder_name', $account_holder);
    }

    wp_redirect(admin_url('admin.php?page=wc-bank-transfer-manager'));
    exit;
});

// Actualizar estado del pago y el estado del pedido
add_action('admin_post_update_payment_status', function () {
    if (!current_user_can('manage_woocommerce')) {
        return;
    }

    $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
    $payment_status = isset($_POST['payment_confirmed']) ? sanitize_text_field($_POST['payment_confirmed']) : 'no';

    if ($order_id) {
        // Actualiza el meta _payment_confirmed
        update_post_meta($order_id, '_payment_confirmed', $payment_status);

        // Obtiene el pedido
        $order = wc_get_order($order_id);
        if ($order) {
            if ($payment_status === 'yes' && $order->get_status() !== 'completed') {
                // Si se confirma el pago, cambia el estado del pedido a completado
                $order->update_status('completed', __('Pago confirmado desde el gestor de transferencias bancarias.', 'woocommerce-bank-transfer'));
            } elseif ($payment_status === 'no' && $order->get_status() === 'completed') {
                // Si se desconfirma el pago y el pedido estaba completado, cambiarlo a "on-hold"
                $order->update_status('on-hold', __('Pago desconfirmado desde el gestor de transferencias bancarias.', 'woocommerce-bank-transfer'));
            }
        }
    }

    wp_redirect(admin_url('admin.php?page=wc-bank-transfer-manager'));
    exit;
});


// Confirmar automáticamente el pago por transferencia bancaria cuando el pedido pase a "processing"
add_action('woocommerce_order_status_processing', function ($order_id) {
    $order = wc_get_order($order_id);
    if (!$order) return;

    $payment_method = $order->get_payment_method();
    if ($payment_method === 'bacs') {
        update_post_meta($order_id, '_payment_confirmed', 'yes');
    }
});

// Marcar como NO confirmado si el pedido cambia a cualquier estado diferente de "processing"
add_action('woocommerce_order_status_changed', function ($order_id, $from_status, $to_status) {
    $order = wc_get_order($order_id);
    if (!$order) return;

    $payment_method = $order->get_payment_method();
    if ($payment_method === 'bacs' && $to_status !== 'processing') {
        update_post_meta($order_id, '_payment_confirmed', 'no');
    }
}, 10, 3);

// Actualizar estado del pago y el estado del pedido desde el plugin
add_action('admin_post_update_payment_status', function () {
    if (!current_user_can('manage_woocommerce')) {
        return;
    }

    $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
    $payment_status = isset($_POST['payment_confirmed']) ? sanitize_text_field($_POST['payment_confirmed']) : 'no';

    if ($order_id) {
        update_post_meta($order_id, '_payment_confirmed', $payment_status);

        // Evitar bucles infinitos
        if (get_post_meta($order_id, '_updating_status', true)) {
            return;
        }
        update_post_meta($order_id, '_updating_status', 'yes');

        $order = wc_get_order($order_id);
        if ($order) {
            if ($payment_status === 'yes' && $order->get_status() !== 'processing') {
                // Si se confirma el pago, cambia el estado del pedido a "processing"
                $order->update_status('processing', __('Pago confirmado desde el gestor de transferencias bancarias.', 'woocommerce-bank-transfer'));
            } elseif ($payment_status === 'no' && $order->get_status() === 'processing') {
                // Si se desconfirma el pago, cambiarlo a "on-hold"
                $order->update_status('on-hold', __('Pago desconfirmado desde el gestor de transferencias bancarias.', 'woocommerce-bank-transfer'));
            }
        }

        // Eliminar el flag de seguridad
        delete_post_meta($order_id, '_updating_status');
    }

    wp_redirect(admin_url('admin.php?page=wc-bank-transfer-manager'));
    exit;
});

